log

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2020 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const CAIC001D string = "CAIC001D Debug mode is enabled"

DEBUG MESSAGES

const CAIC001E string = "CAIC001E Error getting the AWS resource type from environment variable '%s' or flag '-%s'"

ERROR MESSAGES

const CAIC001I string = "CAIC001I Retrieving AWS IAM credential for resource type '%s'"

INFO MESSAGES

const CAIC002E string = "CAIC002E Error getting the AWS resource type. %s"
const CAIC002I string = "CAIC002I Successfully retrieved AWS IAM credential"
const CAIC003E string = "CAIC003E Failed to retrieve the AWS IAM Credential for resource '%s'. %s"
const CAIC003I string = "CAIC003I Successfully created the Conjur authentication request"
const CAIC004E string = "CAIC004E Failed to get Conjur authentication request. %s"
const CAIC004I string = "CAIC004I Attempting to authenticate to conjur: authnUrl=%s, login=%s, account=%s"
const CAIC005E string = "CAIC005E Failed to initialize Conjur HTTP Client. %s"
const CAIC005I string = "CAIC005I Attempting to authenticate to conjur '%s'"
const CAIC006E string = "CAIC006E Error getting Conjur authentication url environment variable '%s'  or flag '-%s'"
const CAIC006I string = "CAIC006I Successfully authenticated to conjur with login '%s'"
const CAIC007E string = "CAIC007E Failed to authenticate to Conjur. %s"
const CAIC007I string = "CAIC007I Successfully wrote access token to '%s'"
const CAIC008E string = "CAIC008E Failure to load Conjur config. %s"
const CAIC009E string = "CAIC009E Error getting the Conjur login environment variable '%s' or flag '-%s'"
const CAIC010E string = "CAIC010E Failed to write access token to '%s'. %s"
const CAIC011E string = "CAIC011E Failed to retrieve secret '%s'. %s"
const CAIC012E string = "CAIC012E Error getting the Conjur account environment variables '%s' or flag '-%s'"
const CAIC013E string = "CAIC012E Error getting the Conjur appliance URL environment variables '%s' or flag '-%s'"

Variables

This section is empty.

Functions

func Debug

func Debug(infoMessage string, args ...interface{})

Debug write debig to log

func EnableDebugMode

func EnableDebugMode()

EnableDebugMode Enable debug mode

func EnableSilence

func EnableSilence()

EnableSilence will only print errors

func Error

func Error(message string, args ...interface{})

Error write error to log

func Info

func Info(message string, args ...interface{})

Info write info to log

func RecordedError

func RecordedError(errorMessage string, args ...interface{}) error

RecordedError write error to logs and return error object

func Warn

func Warn(message string, args ...interface{})

Warn write warn to log

Types

This section is empty.

Jump to